@@ -1,8 +1,6 @@
-from dataclasses import field
+from dataclasses import field, dataclass
 from ai_harness import harnessutils as aiutils
 
-from ai_transformersx.models import *
-
 log = aiutils.getLogger('task')
 
 
