@@ -3,6 +3,9 @@ from transformers import ElectraPreTrainedModel, ElectraModel
 from transformers.file_utils import add_start_docstrings_to_callable
 from transformers.modeling_bert import BertPooler
 from transformers.modeling_electra import ELECTRA_INPUTS_DOCSTRING
+from ai_harness import harnessutils as utils
+
+log = utils.getLogger('task')
 
 
 class ElectraForSequenceClassification(ElectraPreTrainedModel):
@@ -14,6 +17,7 @@ class ElectraForSequenceClassification(ElectraPreTrainedModel):
         self.dropout = nn.Dropout(config.hidden_dropout_prob)
         self.classifier = nn.Linear(config.hidden_size, config.num_labels)
         self.init_weights()
+        self._index = 0
 
     @add_start_docstrings_to_callable(ELECTRA_INPUTS_DOCSTRING)
     def forward(
@@ -90,4 +94,9 @@ class ElectraForSequenceClassification(ElectraPreTrainedModel):
                 loss = loss_fct(logits.view(-1, self.config.num_labels), labels.view(-1))
             outputs = (loss,) + outputs
 
+        if self._index % 10000 == 0:
+            log.info((outputs, labels))
+        else:
+            self._index = self._index + 1
+
         return outputs  # (loss), logits,
